@@ -17,84 +17,15 @@
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
-import datetime
-import sys
+from datetime import datetime, timezone
 from typing import List, Optional
-from uuid import uuid4
+from uuid import uuid4, UUID
 
-from . import HashType
+from . import ThisTool, Tool
 from .component import Component
 from ..parser import BaseParser
 
 
-class Tool:
-    """
-    This is out internal representation of the toolType complex type within the CycloneDX standard.
-
-    Tool(s) are the things used in the creation of the BOM.
-
-    .. note::
-        See the CycloneDX Schema for toolType: https://cyclonedx.org/docs/1.3/#type_toolType
-    """
-
-    def __init__(self, vendor: str, name: str, version: str, hashes: Optional[List[HashType]] = None) -> None:
-        self._vendor = vendor
-        self._name = name
-        self._version = version
-        self._hashes: List[HashType] = hashes or []
-
-    def get_hashes(self) -> List[HashType]:
-        """
-        List of cryptographic hashes that identify this version of this Tool.
-
-        Returns:
-            `List` of `HashType` objects where there are any hashes, else an empty `List`.
-        """
-        return self._hashes
-
-    def get_name(self) -> str:
-        """
-        The name of this Tool.
-
-        Returns:
-            `str` representing the name of the Tool
-        """
-        return self._name
-
-    def get_vendor(self) -> str:
-        """
-        The vendor of this Tool.
-
-        Returns:
-            `str` representing the vendor of the Tool
-        """
-        return self._vendor
-
-    def get_version(self) -> str:
-        """
-        The version of this Tool.
-
-        Returns:
-            `str` representing the version of the Tool
-        """
-        return self._version
-
-    def __repr__(self) -> str:
-        return '<Tool {}:{}:{}>'.format(self._vendor, self._name, self._version)
-
-
-if sys.version_info >= (3, 8):
-    from importlib.metadata import version as meta_version
-else:
-    from importlib_metadata import version as meta_version
-
-try:
-    __ThisToolVersion: Optional[str] = str(meta_version('cyclonedx-python-lib'))  # type: ignore[no-untyped-call]
-except Exception:
-    __ThisToolVersion = None
-ThisTool = Tool(vendor='CycloneDX', name='cyclonedx-python-lib', version=__ThisToolVersion or 'UNKNOWN')
-
-
 class BomMetaData:
     """
     This is our internal representation of the metadata complex type within the CycloneDX standard.
@@ -104,10 +35,27 @@ class BomMetaData:
     """
 
     def __init__(self, tools: Optional[List[Tool]] = None) -> None:
-        self._timestamp = datetime.datetime.now(tz=datetime.timezone.utc)
-        self._tools: List[Tool] = tools if tools else []
-        if len(self._tools) < 1:
-            self._tools.append(ThisTool)
+        self.timestamp = datetime.now(tz=timezone.utc)
+        self.tools = tools if tools else []
+
+        if not self.tools:
+            self.add_tool(ThisTool)
+
+        self.component: Optional[Component] = None
+
+    @property
+    def tools(self) -> List[Tool]:
+        """
+        Tools used to create this BOM.
+
+        Returns:
+            `List` of `Tool` objects where there are any, else an empty `List`.
+        """
+        return self._tools
+
+    @tools.setter
+    def tools(self, tools: List[Tool]) -> None:
+        self._tools = tools
 
     def add_tool(self, tool: Tool) -> None:
         """
@@ -120,23 +68,43 @@ class BomMetaData:
         """
         self._tools.append(tool)
 
-    def get_timestamp(self) -> datetime.datetime:
+    @property
+    def timestamp(self) -> datetime:
         """
         The date and time (in UTC) when this BomMetaData was created.
 
         Returns:
-            `datetime.datetime` instance in UTC timezone
+            `datetime` instance in UTC timezone
         """
         return self._timestamp
 
-    def get_tools(self) -> List[Tool]:
+    @timestamp.setter
+    def timestamp(self, timestamp: datetime) -> None:
+        self._timestamp = timestamp
+
+    @property
+    def component(self) -> Optional[Component]:
         """
-        Tools used to create this BOM.
+        The (optional) component that the BOM describes.
 
         Returns:
-            `List` of `Tool` objects where there are any, else an empty `List`.
+            `cyclonedx.model.component.Component` instance for this Bom Metadata.
         """
-        return self._tools
+        return self._component
+
+    @component.setter
+    def component(self, component: Component) -> None:
+        """
+        The (optional) component that the BOM describes.
+
+        Args:
+            component
+                `cyclonedx.model.component.Component` instance to add to this Bom Metadata.
+
+        Returns:
+            None
+        """
+        self._component = component
 
 
 class Bom:
@@ -172,10 +140,55 @@ class Bom:
         Returns:
             New, empty `cyclonedx.model.bom.Bom` instance.
         """
-        self._uuid = uuid4()
-        self._metadata: BomMetaData = BomMetaData()
+        self.uuid = uuid4()
+        self.metadata = BomMetaData()
         self._components: List[Component] = []
 
+    @property
+    def uuid(self) -> UUID:
+        """
+        Unique UUID for this BOM
+
+        Returns:
+            `UUID` instance
+        """
+        return self.__uuid
+
+    @uuid.setter
+    def uuid(self, uuid: UUID) -> None:
+        self.__uuid = uuid
+
+    @property
+    def metadata(self) -> BomMetaData:
+        """
+        Get our internal metadata object for this Bom.
+
+        Returns:
+            Metadata object instance for this Bom.
+
+        .. note::
+            See the CycloneDX Schema for Bom metadata: https://cyclonedx.org/docs/1.3/#type_metadata
+        """
+        return self._metadata
+
+    @metadata.setter
+    def metadata(self, metadata: BomMetaData) -> None:
+        self._metadata = metadata
+
+    @property
+    def components(self) -> List[Component]:
+        """
+        Get all the Components currently in this Bom.
+
+        Returns:
+             List of all Components in this Bom.
+        """
+        return self._components
+
+    @components.setter
+    def components(self, components: List[Component]) -> None:
+        self._components = components
+
     def add_component(self, component: Component) -> None:
         """
         Add a Component to this Bom instance.
@@ -201,7 +214,7 @@ class Bom:
         Returns:
             None
         """
-        self._components = self._components + components
+        self.components = self._components + components
 
     def component_count(self) -> int:
         """
@@ -212,7 +225,7 @@ class Bom:
         """
         return len(self._components)
 
-    def get_component_by_purl(self, purl: str) -> Optional[Component]:
+    def get_component_by_purl(self, purl: Optional[str]) -> Optional[Component]:
         """
         Get a Component already in the Bom by it's PURL
 
@@ -223,33 +236,13 @@ class Bom:
         Returns:
             `Component` or `None`
         """
-        found = list(filter(lambda x: x.get_purl() == purl, self._components))
-        if len(found) == 1:
-            return found[0]
+        if purl:
+            found = list(filter(lambda x: x.purl == purl, self.components))
+            if len(found) == 1:
+                return found[0]
 
         return None
 
-    def get_components(self) -> List[Component]:
-        """
-        Get all the Components currently in this Bom.
-
-        Returns:
-             List of all Components in this Bom.
-        """
-        return self._components
-
-    def get_metadata(self) -> BomMetaData:
-        """
-        Get our internal metadata object for this Bom.
-
-        Returns:
-            Metadata object instance for this Bom.
-
-        .. note::
-            See the CycloneDX Schema for Bom metadata: https://cyclonedx.org/docs/1.3/#type_metadata
-        """
-        return self._metadata
-
     def get_urn_uuid(self) -> str:
         """
         Get the unique reference for this Bom.
@@ -257,7 +250,7 @@ class Bom:
         Returns:
             URN formatted UUID that uniquely identified this Bom instance.
         """
-        return 'urn:uuid:{}'.format(self._uuid)
+        return 'urn:uuid:{}'.format(self.__uuid)
 
     def has_component(self, component: Component) -> bool:
         """
@@ -280,7 +273,7 @@ class Bom:
             `bool` - `True` if at least one `cyclonedx.model.component.Component` has at least one Vulnerability,
                 `False` otherwise.
         """
-        for c in self.get_components():
+        for c in self.components:
             if c.has_vulnerabilities():
                 return True
 
