@@ -113,6 +113,9 @@ class Xml(BaseOutput, BaseSchemaVersion):
             for tool in bom_metadata.tools:
                 self._add_tool(parent_element=tools_e, tool=tool)
 
+        if bom_metadata.component:
+            metadata_e.append(self._add_component_element(component=bom_metadata.component))
+
     def _add_component_element(self, component: Component) -> ElementTree.Element:
         element_attributes = {'type': component.type.value}
         if self.component_supports_bom_ref_attribute() and component.bom_ref:
